/**
 * EasyBeans
 * Copyright (C) 2006 Bull S.A.S.
 * Contact: easybeans@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: EasyBeansSFSBLifeCycle.java 5602 2010-10-01 15:49:31Z sauthieg $
 * --------------------------------------------------------------------------
 */

package org.ow2.easybeans.api.bean.lifecycle;

/**
 * Defines the lifecycle of a stateful session bean.
 * @author Florent Benoit
 */
public interface EasyBeansSFSBLifeCycle extends EasyBeansSBLifeCycle {

    /**
     * The PrePassivate and PostActivate callback methods are only called on
     * stateful session bean instances. PrePassivate and PostActivate callback
     * methods should not be defined for stateless session beans. The
     * PrePassivate callback notification signals the intent of the container to
     * passivate the instance.
     */
    void prePassivateEasyBeansLifeCycle();

    /**
     * The PrePassivate and PostActivate callback methods are only called on
     * stateful session bean instances.<br>
     * PrePassivate and PostActivate callback methods should not be defined for
     * stateless session beans.<br>
     * The PostActivate notification signals the instance it has just been
     * reactivated. Because containers automatically maintain the conversational
     * state of a stateful session bean instance when it is passivated, most
     * session beans do not need these notifications.
     */
    void postActivateEasyBeansLifeCycle();
}
