/**
 * EasyBeans
 * Copyright (C) 2006 Bull S.A.S.
 * Contact: easybeans@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: JContainer3MBean.java 5602 2010-10-01 15:49:31Z sauthieg $
 * --------------------------------------------------------------------------
 */

package org.ow2.easybeans.container.management;

import java.net.URL;

import javax.management.MBeanException;

import org.ow2.easybeans.api.EZBContainerException;
import org.ow2.easybeans.jsr77.EJBModuleMBean;
import org.ow2.util.archive.api.ArchiveException;
import org.ow2.util.ee.deploy.api.deployable.IDeployable;

/**
 * MBean for {@link org.ow2.easybeans.container.JContainer3}.
 * @author Guillaume Sauthier
 */
public class JContainer3MBean extends EJBModuleMBean {

    /**
     * Default ModelMBean constructor.
     * @throws MBeanException if ModelMBean creation fails.
     */
    public JContainer3MBean() throws MBeanException {
        super();
    }

    /**
     * Start this container.
     */
    public void start() {
        try {
            getManagedComponent().start();
        } catch (EZBContainerException ece) {
            getLogger().error("Cannot start the EJB Container", ece);
            throw new RuntimeException(ece);
        }
    }

    /**
     * Gets the URL of the archive of this container.
     * @return the URL of the archive of this container.
     */
    public URL getUrl() {
        try {
            IDeployable<?> deployable = getManagedComponent().getDeployable();
            // Try to get the original deployable if not null
            if (deployable.getOriginalDeployable() != null) {
                deployable = deployable.getOriginalDeployable();
            }

            return deployable.getArchive().getURL();
        } catch (ArchiveException e) {
            getLogger().error("Cannot get URL on the archive", e);
            throw new RuntimeException(e);
        }
    }

    /**
     * Stop this container.
     */
    public void stop() {
        getManagedComponent().stop();
    }


}
