/**
 * EasyBeans
 * Copyright (C) 2006 Bull S.A.S.
 * Contact: easybeans@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: TestRemoteAnnotation02.java 5602 2010-10-01 15:49:31Z sauthieg $
 * --------------------------------------------------------------------------
 */
package org.ow2.easybeans.tests.sessionbean.misc;

import org.ow2.easybeans.tests.common.ejbs.stateless.containermanaged.basic.ItfSessionBeanTester01;
import org.ow2.easybeans.tests.common.ejbs.stateless.containermanaged.basic.SLSBSessionBeanTester02;
import org.ow2.easybeans.tests.common.helper.EJBHelper;
import org.testng.annotations.BeforeMethod;
import org.testng.annotations.Test;

/**
 * Verifies if a bean that has the annotations local and remote in the superclass can be deployed.
 * @reference JSR 220-FINAL RELEASE
 * @requirement Application Server must be running; the beans
 *              SLSBSessionBeanTester02, SLSBDeployTest03, SFSBDeployTest03,
 *              SLSBDeployTest04 and SFSBDeployTest04 must be deployed.
 * @setup gets a reference of the bean SLSBSessionBeanTester02.
 * @author Gisele Pinheiro Souza
 * @author Eduardo Studzinski Estima de Castro
 */
public class TestRemoteAnnotation02 {

    /**
     * Bean used during the test.
     */
    private ItfSessionBeanTester01 bean;

    /**
     * Gets an instance of the bean.
     * @throws Exception if an error occurs.
     */
    @BeforeMethod
    public void setup() throws Exception {
        // Gets a bean instance.
        bean = EJBHelper.getBeanRemoteInstance(SLSBSessionBeanTester02.class, ItfSessionBeanTester01.class);
    }

    /**
     * Verifies if stateful bean that has the local interface defined by the
     * annotation local and does not implement the local interface can be
     * deployed.
     * @input -
     * @output the correct method execution.
     */
    @Test
    public void testSFLocal() {
        bean.testSFLocal();
    }

    /**
     * Verifies if stateless bean that has the local interface defined by the
     * annotation local and does not implement the local interface can be
     * deployed.
     * @input -
     * @output the correct method execution.
     */
    @Test
    public void testSLLocal() {
        bean.testSLLocal();
    }

    /**
     * Verifies if stateful bean that has the remote interface defined by the
     * annotation remote and does not implement the local interface can be
     * deployed.
     * @input -
     * @output the correct method execution.
     */
    @Test
    public void testSFRemote() {
        bean.testSFRemote();
    }

    /**
     * Verifies if stateless bean that has the remote interface defined by the
     * annotation remote and does not implement the local interface can be
     * deployed.
     * @input -
     * @output the correct method execution.
     */
    @Test
    public void testSLRemote() {
        bean.testSLLocal();
    }
}
